@@ -170,8 +170,8 @@ class Viewer(ViewerParent):
     _model_name = Unicode('ViewerModel').tag(sync=True)
     _view_module = Unicode('itk-jupyter-widgets').tag(sync=True)
     _model_module = Unicode('itk-jupyter-widgets').tag(sync=True)
-    _view_module_version = Unicode('^0.16.0').tag(sync=True)
-    _model_module_version = Unicode('^0.16.0').tag(sync=True)
+    _view_module_version = Unicode('^0.16.1').tag(sync=True)
+    _model_module_version = Unicode('^0.16.1').tag(sync=True)
     image = ITKImage(default_value=None, allow_none=True, help="Image to visualize.").tag(sync=False, **itkimage_serialization)
     rendered_image = ITKImage(default_value=None, allow_none=True).tag(sync=True, **itkimage_serialization)
     _rendering_image = CBool(default_value=False, help="We are currently volume rendering the image.").tag(sync=True)
@@ -295,6 +295,7 @@ class Viewer(ViewerParent):
             else:
                 scale_factors = self._find_scale_factors(self.size_limit_3d, dimension, size)
             self._scale_factors = np.array(scale_factors, dtype=np.uint8)
+            self.shrinker.SetInput(self.image)
             self.shrinker.SetShrinkFactors(scale_factors[:dimension])
 
             region = itk.ImageRegion[dimension]()
@@ -305,6 +306,7 @@ class Viewer(ViewerParent):
             region.PadByRadius(1)
             region.Crop(self.image.GetLargestPossibleRegion())
 
+            self.extractor.SetInput(self.image)
             self.extractor.SetExtractionRegion(region)
 
             size = region.GetSize()
